searchData={"items":[{"type":"module","doc":"SmsUp is used to send sms throught [SmsUP](https://smsup.ch) (other api may be integrated easily) by implementing the same behaviour.\nThis module provides delegates to the internal modules for sending sms and the distributed One Time Password store.\nFor the One Time Password functionality if you are part of a cluster the librairy uses mnesia to distibute the store accross the nodes.","title":"SmsUp","ref":"SmsUp.html"},{"type":"function","doc":"Send a sms with the chosen Sender Module.\nConfiguration is available as :\n`\nconfig :sms_up, :deliver_module, MODULE\n`\nMODULE can be SmsUp.Delivery.LoggerDelivery (default) or SmsUp.Delivery.SmsUpDelivery.\n\nReturns a ok tuple containing the message body and the number for which it was sent to or an error tuple with the reason.","title":"SmsUp.send_sms/3","ref":"SmsUp.html#send_sms/3"},{"type":"function","doc":"iex> SmsUp.send_sms(\"+41765556677\", \"message\")\n    {:ok, %{to: \"+41765556677\", body: \"message\"}}","title":"Examples - SmsUp.send_sms/3","ref":"SmsUp.html#send_sms/3-examples"},{"type":"function","doc":"Generate a pin code for the given id and store it in a mnesia database.\nReturns the generated pin code.","title":"SmsUp.store/1","ref":"SmsUp.html#store/1"},{"type":"function","doc":"iex> SmsUp.store(\"user@email.ch\")\n    {:ok, \"123456\"}","title":"Examples - SmsUp.store/1","ref":"SmsUp.html#store/1-examples"},{"type":"function","doc":"Validate a pin code along with the user id and tells if the provided pin is correct or not.\nReturns a tupple containing true or false regarding the result.","title":"SmsUp.validate/2","ref":"SmsUp.html#validate/2"},{"type":"function","doc":"iex> SmsUp.validate(\"user@email.ch\", \"Good Pin\")\n    {:ok, true}\n\n    iex> SmsUp.validate(\"user@email.ch\", \"Wrong Pin\")\n    {:ok, false}","title":"Examples - SmsUp.validate/2","ref":"SmsUp.html#validate/2-examples"},{"type":"module","doc":"","title":"SmsUp.Db.Number","ref":"SmsUp.Db.Number.html"},{"type":"module","doc":"","title":"SmsUp.Db.Pin","ref":"SmsUp.Db.Pin.html"},{"type":"module","doc":"Print the sms to the console and do not send it to any API.\nUsefull for dev environment and testing.","title":"SmsUp.Delivery.LoggerDelivery","ref":"SmsUp.Delivery.LoggerDelivery.html"},{"type":"function","doc":"Deliver the SMS to the console.\nProvide a valid international number, the body of the message and\na optional list of options (mostly used by real sms api).\nIt is also possible to pass force_error to simulate a delivery failure","title":"SmsUp.Delivery.LoggerDelivery.deliver/3","ref":"SmsUp.Delivery.LoggerDelivery.html#deliver/3"},{"type":"function","doc":"iex> SmsUp.Delivery.LoggerDelivery.deliver(\"+41765556677\", \"Hello\")\n    {:ok, %{to: \"+41765556677\", body: \"Hello\", options: []}}\n\n    iex> SmsUp.Delivery.LoggerDelivery.deliver(\"+41765556677\", \"Hello\", option: 1)\n    {:ok, %{to: \"+41765556677\", body: \"Hello\", options: [option: 1]}}\n\n    iex> SmsUp.Delivery.LoggerDelivery.deliver(\"+41765556677\", \"Hello\", force_error: \"Ooops\")\n    {:error, \"Ooops\"}","title":"Examples - SmsUp.Delivery.LoggerDelivery.deliver/3","ref":"SmsUp.Delivery.LoggerDelivery.html#deliver/3-examples"},{"type":"module","doc":"Deliver the sms throught SMS Up plateform with your API key.","title":"SmsUp.Delivery.SmsUpDelivery","ref":"SmsUp.Delivery.SmsUpDelivery.html"},{"type":"function","doc":"Deliver the SMS to the real API.\nProvide a valid international number, the body of the message and\na optional list of options:\n* pushtype: The push type (alert or marketing)\n* delay: Sending date Y-m-d H:i:s\n* sender: Allows you to customize the sender\n* gsmsmsid: An id of your choice to link it to its delivery report\n\nCan return the following errors from SMS UP:\n* Authentication error\n* XML error\n* Not enough credits\n* Incorrect date delay\n* Contact list error\n* JSON error\n* Data error\n* Your campaign is currently under moderation\n* Unknown error\n\nDo not forget to indicate your API key in config:\n`\nconfig :sms_up, api_key: MY_KEY\n`","title":"SmsUp.Delivery.SmsUpDelivery.deliver/3","ref":"SmsUp.Delivery.SmsUpDelivery.html#deliver/3"},{"type":"function","doc":"iex> SmsUp.Delivery.SmsUpDelivery.deliver(\"+41765556677\", \"Hello\")\n    {:ok, %{to: \"+41765556677\", body: \"Hello\", options: []}}\n\n    iex> SmsUp.Delivery.SmsUpDelivery.deliver(\"+41765556677\", \"Hello\", [sender: \"Company\"])\n    {:ok, %{to: \"+41765556677\", body: \"Hello\", options: [sender: \"Company\"]}}","title":"Examples - SmsUp.Delivery.SmsUpDelivery.deliver/3","ref":"SmsUp.Delivery.SmsUpDelivery.html#deliver/3-examples"},{"type":"module","doc":"This module provides function to validate phone number formats.","title":"SmsUp.Numbers.PhoneValidator","ref":"SmsUp.Numbers.PhoneValidator.html"},{"type":"function","doc":"Format the given number to international format.\n\nReturns a ok tupple with the formated number or an erro tupple and the reason.","title":"SmsUp.Numbers.PhoneValidator.format/2","ref":"SmsUp.Numbers.PhoneValidator.html#format/2"},{"type":"function","doc":"iex> SmsUp.Numbers.PhoneValidator.format(\"+41765556677\", \"CH\")\n    {:ok, \"+41765556677\"}\n\n    iex> SmsUp.Numbers.PhoneValidator.format(\"0765556677\", \"CH\")\n    {:ok, \"+41765556677\"}\n\n    iex> SmsUp.Numbers.PhoneValidator.format(\"765556677\", \"CH\")\n    {:ok, \"+41765556677\"}\n\n    iex> SmsUp.Numbers.PhoneValidator.format(\"0630772288\", \"FR\")\n    {:ok, \"+33630772288\"}\n\n    iex> SmsUp.Numbers.PhoneValidator.format(\"0630772288\", \"ZZ\")\n    {:error, \"Invalid country calling code\"}\n\n    iex> SmsUp.Numbers.PhoneValidator.format(\"Hello\", \"FR\")\n    {:error, \"The string supplied did not seem to be a phone number\"}","title":"Examples - SmsUp.Numbers.PhoneValidator.format/2","ref":"SmsUp.Numbers.PhoneValidator.html#format/2-examples"},{"type":"function","doc":"Check if the number seems to be valid format wise.\n\nReturns true or false.","title":"SmsUp.Numbers.PhoneValidator.is_valid_number?/1","ref":"SmsUp.Numbers.PhoneValidator.html#is_valid_number?/1"},{"type":"function","doc":"iex> SmsUp.Numbers.PhoneValidator.is_valid_number?(\"+41765556677\")\n    true\n\n    iex> SmsUp.Numbers.PhoneValidator.is_valid_number?(\"0765556677\")\n    false\n\n    iex> SmsUp.Numbers.PhoneValidator.is_valid_number?(\"555\")\n    false\n\n    iex> SmsUp.Numbers.PhoneValidator.is_valid_number?(\"hello\")\n    false","title":"Examples - SmsUp.Numbers.PhoneValidator.is_valid_number?/1","ref":"SmsUp.Numbers.PhoneValidator.html#is_valid_number?/1-examples"},{"type":"module","doc":"This module deals with generating random pin codes.","title":"SmsUp.Pin.Generator","ref":"SmsUp.Pin.Generator.html"},{"type":"function","doc":"Generate a random pin number of the given length (min: 1, max: 10).\n\n  Returns a pin of the given length as a string.","title":"SmsUp.Pin.Generator.generate_pin/1","ref":"SmsUp.Pin.Generator.html#generate_pin/1"},{"type":"function","doc":"iex> :rand.seed(:exsss, {10, 20, 30})\n    iex> SmsUp.Pin.Generator.generate_pin()\n    {:ok, \"278950\"}\n\n    iex> :rand.seed(:exsss, {10, 20, 30})\n    iex> SmsUp.Pin.Generator.generate_pin(4)\n    {:ok, \"4819\"}\n\n    iex> :rand.seed(:exsss, {10, 20, 30})\n    iex> SmsUp.Pin.Generator.generate_pin(100)\n    {:ok, \"8317504629\"}\n\n    iex> SmsUp.Pin.Generator.generate_pin(0)\n    {:error, \"invalid size of 0, please use a positive integer\"}\n\n    iex> SmsUp.Pin.Generator.generate_pin(-6)\n    {:error, \"invalid size of -6, please use a positive integer\"}","title":"Examples (:rand.seed is used here for doctest) - SmsUp.Pin.Generator.generate_pin/1","ref":"SmsUp.Pin.Generator.html#generate_pin/1-examples-rand-seed-is-used-here-for-doctest"},{"type":"module","doc":"This module stores random pin associated with an id to be checked later.\nDefault validity is 15 minutes and is configurable (value to be given in minutes):\n`\nconfig :sms_up, pin_validity: 20\n`\n\nDefault token size is 6 and can be modified also:\n`\nconfig :sms_up, :pin_size, 4\n`","title":"SmsUp.Pin.Store","ref":"SmsUp.Pin.Store.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"SmsUp.Pin.Store.child_spec/1","ref":"SmsUp.Pin.Store.html#child_spec/1"},{"type":"function","doc":"Generate a pin code for the given id and store it in a mnesia database.\nReturns the generated pin code.","title":"SmsUp.Pin.Store.store/1","ref":"SmsUp.Pin.Store.html#store/1"},{"type":"function","doc":"iex> SmsUp.Pin.Store.store(\"user@email.ch\")\n    {:ok, \"123456\"}","title":"Examples - SmsUp.Pin.Store.store/1","ref":"SmsUp.Pin.Store.html#store/1-examples"},{"type":"function","doc":"Validate a pin code along with the user id and tells if the provided pin is correct or not.\nReturns a tupple containing true or false regarding the result.","title":"SmsUp.Pin.Store.validate/2","ref":"SmsUp.Pin.Store.html#validate/2"},{"type":"function","doc":"iex> SmsUp.Pin.Store.validate(\"user@email.ch\", \"Good Pin\")\n    {:ok, true}\n\n    iex> SmsUp.Pin.Store.validate(\"user@email.ch\", \"Wrong Pin\")\n    {:ok, false}","title":"Examples - SmsUp.Pin.Store.validate/2","ref":"SmsUp.Pin.Store.html#validate/2-examples"},{"type":"module","doc":"SMS sender api that can accept a configurable deliver for sending successfull messages.","title":"SmsUp.Sender","ref":"SmsUp.Sender.html"},{"type":"function","doc":"","title":"SmsUp.Sender.deliver/3","ref":"SmsUp.Sender.html#deliver/3"},{"type":"function","doc":"Send a sms with the chosen Sender Module with an international formated number.\n\nConfiguration is available as :\n`\nconfig :sms_up, deliver_module: MODULE\n`\n\nMODULE can be:\n* SmsUp.Delivery.LoggerDelivery (default)\n* SmsUp.Delivery.SmsUpDelivery.\n\nReturns a ok tuple containing the message body and the number for which it was sent to or an error tuple with the reason.","title":"SmsUp.Sender.send_sms/3","ref":"SmsUp.Sender.html#send_sms/3"},{"type":"function","doc":"iex> SmsUp.send_sms(\"+41765556677\", \"message\", [])\n    {:ok, %{to: \"+41765556677\", body: \"message\", options: []}}\n\n    iex> SmsUp.send_sms(\"Hello\", \"FR\", [])\n    {:error, \"Hello is not a valid number\"}","title":"Examples - SmsUp.Sender.send_sms/3","ref":"SmsUp.Sender.html#send_sms/3-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}